@@ -138,8 +138,8 @@ sub is_equal {
     return perl5i::2::equal::are_equal($$$self, $other);
 }
 
-
-sub perl {
+*perl = \&as_perl;
+sub as_perl {
     require Data::Dumper;
 
     state $options = [qw(Terse Sortkeys Deparse)];
@@ -162,9 +162,9 @@ sub dump {
 
     my $format = $args{format} // "perl";
     state $dumpers = {
-        json    => "_dump_as_json",
-        yaml    => "_dump_as_yaml",
-        perl    => "perl",
+        json    => "as_json",
+        yaml    => "as_yaml",
+        perl    => "as_perl",
     };
 
     my $dumper = $dumpers->{$format};
@@ -173,8 +173,7 @@ sub dump {
     return $self->$dumper(%args);
 }
 
-
-sub _dump_as_json {
+sub as_json {
     require JSON;
     my $json = JSON->new
                     ->utf8
@@ -198,7 +197,7 @@ sub _dump_as_json {
     return $json->encode(${${$_[0]}});
 }
 
-sub _dump_as_yaml {
+sub as_yaml {
     require YAML::Any;
     return YAML::Any::Dump(${${$_[0]}});
 }
